<?php
function doctor_create_reservations_table(): void
{

	require_once(ABSPATH . '/wp-admin/includes/upgrade.php');
	global $wpdb;
	global $wp_queries, $charset_collate;

	$reservations = $wpdb->prefix . "reservations";
	$charset_collate = '';
	$charset_collate .= " COLLATE utf8_general_ci";

	if ($wpdb->get_var("SHOW TABLES LIKE '{$reservations}'") != $reservations) {

		$sql = "CREATE TABLE IF NOT EXISTS {$reservations} (
			id BIGINT(20) UNSIGNED AUTO_INCREMENT,
			c_name VARCHAR(100) NOT NULL,
			phone VARCHAR(50) NOT NULL,
			service VARCHAR(100) NOT NULL,
			details VARCHAR(100) NULL,
			reservation_date DATETIME DEFAULT CURRENT_TIMESTAMP,
			PRIMARY KEY (id) ) {$charset_collate} ";
		dbDelta($sql);
	}
}

function doctor_store_reservations($data)
{
	$data = [
		'c_name'         => sanitize_text_field($data['name']),
		'phone'         => sanitize_text_field($data['phone']),
		'service'         => sanitize_text_field($data['service']),
		'details'         => sanitize_text_field($data['details']),
	];

	global $wpdb;
	$table_name = $wpdb->prefix . "reservations";

	$reservation = $wpdb->insert($table_name, $data);

	if (!$reservation) {
		$errors = new WP_Error();

		$errors->add('saving', 'there is an error while saving reservation please try again.');

		return $errors;
	}
	
    send_new_reservation_done_admin__email($data);
	$redirect_url = doctor_get_template_url('page-thank.php');
	wp_redirect($redirect_url);
	exit;
	
}

function doctor_get_reservations_by_id(int $post_id)
{
	global $wpdb;

	$table_name = $wpdb->prefix . 'reservations';

	$query = $wpdb->prepare("SELECT * FROM $table_name WHERE id = %d", $post_id);

	$post = $wpdb->get_row($query, ARRAY_A);

	if ($post === null) {
		echo 'Post not found.';
	} elseif ($post === false) {
		echo 'Error executing query: ' . $wpdb->last_error;
	} else {
		return $post;
	}
}

function hexToRgba($color)
{
	$color = ltrim($color, '#');

	$r = hexdec(substr($color, 0, 2));
	$g = hexdec(substr($color, 2, 2));
	$b = hexdec(substr($color, 4, 2));

	$rgba = "$r, $g, $b,";

	return $rgba;
}

function doctor_get_template_url(string $template)
{
    $args = [
        'meta_key'   => '_wp_page_template',
        'meta_value' => $template,
        'post_type'  => 'page',
        'post_status' => 'publish',
        'numberposts' => 1
    ];

    $pages = get_pages($args);

    if (!$pages || empty($pages)) {
        error_log("No pages found with template: " . $template);
        return false;
    }

    $template_page = $pages[0];

    return get_permalink($template_page->ID);
}

function doctor_res_fromemail($email)
{
  $doctorfrom = get_option('admin_email');

  return $doctorfrom;
}

function doctor_res_fromname($email)
{
  $doctorfrom = get_option('blogname');
  return $doctorfrom;
}
add_filter('wp_mail_from', 'doctor_res_fromemail');
add_filter('wp_mail_from_name', 'doctor_res_fromname');

function send_new_reservation_done_admin__email($data)
{
  $logo_dark = get_option('doctor_logo_img');
  $to = get_option('doctor_email');
  $subject = 'Doctor - New Reservation ';
  $body = '
      <html>
          <head>
              <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
          </head>
          <body>
              <table style="font-family: Verdana,sans-serif; font-size: 13px; color: #374953; width: 700px;margin: auto;border: 1px solid #dddddd;padding: 70px 30px;">
                <tr>
                  <td align="left"><a href="' . DOCTOR_BlogUrl . '" title="doctor"><img src="' . $logo_dark . '" alt="doctor Logo" style="width: 200px;display: block;margin: auto;" ></a></td>
                </tr>
                <tr>
                  <td>&nbsp;</td>
                </tr>
                <tr>
                  <td><h2 style="background-color: #284646; color:#FFF; font-weight: bold; padding: 1em 1em;text-align:center">New Reservation Done </h2></td>
                </tr>
                <tr>
                  <td>&nbsp;</td>
                </tr>
                <tr>
                  <td><p>New User Done Reservation.</p></td>
                </tr>
                <tr>
                  <td>&nbsp;</td>
                </tr>
                <tr>
                  <td>

                  <p> Name: ' . $data['name'] . '</p>
                  <p> Phone: ' . $data['phone'] . '</p>
                  <p> Service: ' . $data['service'] . '</p>
                  <p> Setails: ' . $data['details'] . '</p>
                  </td>
                </tr>
                <tr>
                  <td>&nbsp;</td>
                </tr>
                <tr>
                  <td align="center" style="font-size: 15px;border-top: 1px solid #dddddd;padding: 10px;">
                      <p><i>Thank you!</i><br/><b>doctor.</b></p>
                  </td>
                </tr>
              </table>
          </body>
      </html>';
  $headers  = 'MIME-Version: 1.0' . "\r\n";
  $headers .= 'Content-Type: text/html; charset=UTF-8' . "\r\n";
  $headers .= 'From: =' . get_option('doctor_email') . "\r\n";
  wp_mail($to, $subject, $body, $headers);
}


add_action('login_enqueue_scripts', 'my_login_logo');

function my_login_logo()
{ ?>
	<style type="text/css">
		.login #backtoblog a,
		.login #nav a {
			color: #fff !important;
		}

		body {
			background: <?= get_option('doctor_primaryColor'); ?> !important;
		}

		#login h1 a,
		.login h1 a {
			background-image: url(<?= get_option('doctor_logo_img'); ?>);
			width: 100%;
			height: 100px;
			background-size: contain;
			margin: 0 auto;
		}

		#login form {
			background: <?= get_option('doctor_secondaryColor'); ?> !important;
			border-radius: .5rem;
			border: none !important;
			outline: none !important;
		}

		.login label {
			font-weight: 600 !important;
			color: #fff !important;
		}


		.wp-core-ui p .button:hover {
			background-color: #fff !important;
			border-color: #fff !important;
			color: #000 !important;
		}

		.wp-core-ui p .button {
			background: <?= get_option('doctor_primaryColor'); ?> !important;
			color: #fff !important;
			border: none !important;
			outline: none !important;
		}

		#reg_passmail {
			color: #fff;
		}
	</style>
<?php }

function remove_footer_admin()
{
	echo '<span id="footer-thankyou">Powered by <a href="https://codzilla.net/" target="_blank">Codezilla</a></span>';
}
add_filter('admin_footer_text', 'remove_footer_admin');


